@@ -25,7 +25,7 @@ class CSHLDAP:
             3s to complete. You may optionally restrict the scope by specifying
             a uid, which is roughly equivalent to a search(uid='foo')
         """
-        entries = self.ldap.search_s(self.base,pyldap.SCOPE_SUBTREE,'(uid='+uid+')')
+        entries = self.ldap.search_s(self.base,pyldap.SCOPE_SUBTREE,'(uid='+uid+')', ['*', '+'])
         result = []
         for entry in entries:
             result.append(entry[1])
@@ -34,7 +34,7 @@ class CSHLDAP:
     def member(self, user):
         """ Returns a user as a dict of attributes 
         """
-        return list(self.ldap.search_s(self.base,pyldap.SCOPE_SUBTREE,'(uid='+user+')')[0])[1]
+        return list(self.ldap.search_s(self.base,pyldap.SCOPE_SUBTREE,'(uid='+user+')', ['*', '+'])[0])[1]
 
     def search( self, **kwargs):
         filterstr =''
@@ -43,7 +43,7 @@ class CSHLDAP:
 
         if len(kwargs) > 1:
             filterstr = '(&'+filterstr+')'
-        return self.ldap.search_s(self.base, pyldap.SCOPE_SUBTREE, filterstr)
+        return self.ldap.search_s(self.base, pyldap.SCOPE_SUBTREE, filterstr, ['*', '+'])
 
 
 class KerberosTicket:
